@@ -1,7 +1,7 @@
 /*
     kopetechatwindow.cpp - Chat Window
 
-    Copyright (c) 2002-2005 by Olivier Goffart       <ogoffart@ kde.org>
+    Copyright (c) 2002-2006 by Olivier Goffart       <ogoffart@ kde.org>
     Copyright (c) 2003-2004 by Richard Smith         <kde@metafoo.co.uk>
     Copyright (C) 2002      by James Grant
     Copyright (c) 2002      by Stefan Gehn           <metz AT gehn.net>
@@ -216,6 +216,8 @@ KopeteChatWindow::KopeteChatWindow( QWidget *parent, const char* name )
 
 	KGlobal::config()->setGroup( QString::fromLatin1("ChatWindowSettings") );
 	m_alwaysShowTabs = KGlobal::config()->readBoolEntry( QString::fromLatin1("AlwaysShowTabs"), false );
+	m_showFormatToolbar = KGlobal::config()->readBoolEntry( QString::fromLatin1("Show Format Toolbar"), true );
+	adjustingFormatToolbar = false;
 //	kdDebug( 14010 ) << k_funcinfo << "Open Windows: " << windows.count() << endl;
 	kapp->ref();
 }
@@ -311,10 +313,8 @@ void KopeteChatWindow::initActions(void)
 
 	createStandardStatusBarAction();
 
-	chatSend = new KAction( i18n( "&Send Message" ), QString::fromLatin1( "mail_send" ), 0,
+	chatSend = new KAction( i18n( "&Send Message" ), QString::fromLatin1( "mail_send" ), QKeySequence(Key_Return) ,
 		this, SLOT( slotSendMessage() ), coll, "chat_send" );
-	//Default to 'Return' for sending messages
-	chatSend->setShortcut( QKeySequence(Key_Return) );
 	chatSend->setEnabled( false );
 
  	KStdAction::save ( this, SLOT(slotChatSave()), coll );
@@ -381,7 +381,7 @@ void KopeteChatWindow::initActions(void)
 	toggleAutoSpellCheck = new KToggleAction( i18n( "Automatic Spell Checking" ), QString::null, 0,
 		this, SLOT( toggleAutoSpellChecking() ), coll, "enable_auto_spell_check" );
 	toggleAutoSpellCheck->setChecked( true );
-	
+
 	actionSmileyMenu = new KopeteEmoticonAction( coll, "format_smiley" );
 	actionSmileyMenu->setDelayed( false );
 	connect(actionSmileyMenu, SIGNAL(activated(const QString &)), this, SLOT(slotSmileyActivated(const QString &)));
@@ -420,6 +420,9 @@ void KopeteChatWindow::initActions(void)
 
 	setXMLFile( QString::fromLatin1( "kopetechatwindow.rc" ) );
 	createGUI( 0L );
+
+	// Special handling for remembering whether the format toolbar is visible or not
+	connect ( toolBar("formatToolBar"), SIGNAL(visibilityChanged(bool)), this, SLOT(slotToggleFormatToolbar(bool)) );
 }
 
 const QString KopeteChatWindow::fileContents( const QString &path ) const
@@ -500,14 +503,27 @@ void KopeteChatWindow::updateSpellCheckAction()
 		return;
 
 	if ( m_activeView->editPart()->richTextEnabled() )
+	{
 		toggleAutoSpellCheck->setEnabled( false );
-	else
-		toggleAutoSpellCheck->setEnabled( true );
-
-	if ( m_activeView->editPart()->autoSpellCheckEnabled() )
-		toggleAutoSpellCheck->setChecked( true );
-	else
 		toggleAutoSpellCheck->setChecked( false );
+		m_activeView->editPart()->toggleAutoSpellCheck( false );
+	}
+	else
+	{
+		toggleAutoSpellCheck->setEnabled( true );
+		if ( KopetePrefs::prefs()->spellCheck() )
+		{
+			kdDebug(14000) << k_funcinfo << "spell check enabled" << endl;
+			toggleAutoSpellCheck->setChecked( true );
+			m_activeView->editPart()->toggleAutoSpellCheck(true);
+		}
+		else
+		{
+			kdDebug(14000) << k_funcinfo << "spell check disabled" << endl;
+			toggleAutoSpellCheck->setChecked( false );
+			m_activeView->editPart()->toggleAutoSpellCheck(false);
+		}
+	}
 }
 
 void KopeteChatWindow::slotHistoryUp()
@@ -689,8 +705,12 @@ void KopeteChatWindow::attachChatView( ChatView* newView )
 	connect( newView, SIGNAL(rtfEnabled( ChatView*, bool ) ), this, SLOT( slotRTFEnabled( ChatView*, bool ) ) );
 	connect( newView, SIGNAL(updateStatusIcon( ChatView* ) ), this, SLOT(slotUpdateCaptionIcons( ChatView* ) ) );
 	connect( newView, SIGNAL(updateChatState( ChatView*, int ) ), this, SLOT( updateChatState( ChatView*, int ) ) );
+
 	updateSpellCheckAction();
 	checkDetachEnable();
+	newView->loadChatSettings();
+	connect( newView, SIGNAL(autoSpellCheckEnabled( ChatView*, bool ) ),
+	         this, SLOT( slotAutoSpellCheckEnabled( ChatView*, bool ) ) );
 }
 
 void KopeteChatWindow::checkDetachEnable()
@@ -826,10 +846,11 @@ void KopeteChatWindow::setActiveView( QWidget *widget )
 	{
 		disconnect( m_activeView, SIGNAL( canSendChanged(bool) ), this, SLOT( slotUpdateSendEnabled() ) );
 		guiFactory()->removeClient(m_activeView->msgManager());
+		m_activeView->saveChatSettings();
 	}
 
 	guiFactory()->addClient(view->msgManager());
-	createGUI( view->part() );
+	createGUI( view->editPart() );
 
 	if( m_activeView )
 		m_activeView->setActive( false );
@@ -876,6 +897,7 @@ void KopeteChatWindow::setActiveView( QWidget *widget )
 	updateSpellCheckAction();
 	slotUpdateSendEnabled();
 	m_activeView->editPart()->reloadConfig();
+	m_activeView->loadChatSettings();
 }
 
 void KopeteChatWindow::slotUpdateCaptionIcons( ChatView *view )
@@ -890,7 +912,7 @@ void KopeteChatWindow::slotUpdateCaptionIcons( ChatView *view )
 		if(!c || c->onlineStatus() < contact->onlineStatus())
 			c=contact;
 	}
-	
+
 	if ( view == m_activeView )
  	{
 		QPixmap icon16 = c ? view->msgManager()->contactOnlineStatus( c ).iconFor( c , 16) :
@@ -1012,6 +1034,7 @@ void KopeteChatWindow::readOptions()
 	KConfig *config = KGlobal::config();
 	applyMainWindowSettings( config, QString::fromLatin1( "KopeteChatWindow" ) );
 	config->setGroup( QString::fromLatin1("ChatWindowSettings") );
+	m_showFormatToolbar = config->readBoolEntry( QString::fromLatin1("Show Format Toolbar"), true );
 }
 
 void KopeteChatWindow::saveOptions()
@@ -1026,6 +1049,7 @@ void KopeteChatWindow::saveOptions()
 	if( m_tabBar )
 		config->writeEntry ( QString::fromLatin1("Tab Placement"), m_tabBar->tabPosition() );
 
+	config->writeEntry( QString::fromLatin1("Show Format Toolbar"), m_showFormatToolbar );
 	config->sync();
 }
 
@@ -1055,6 +1079,13 @@ void KopeteChatWindow::slotToggleStatusBar()
 		statusBar()->show();
 }
 
+void KopeteChatWindow::slotToggleFormatToolbar(bool visible)
+{
+	if ( adjustingFormatToolbar )
+		return;
+	m_showFormatToolbar = visible;
+}
+
 void KopeteChatWindow::slotViewMenuBar()
 {
 	if( !menuBar()->isHidden() )
@@ -1075,13 +1106,25 @@ void KopeteChatWindow::slotRTFEnabled( ChatView* cv, bool enabled)
 	if ( cv != m_activeView )
 		return;
 
-	if ( enabled )
+	adjustingFormatToolbar = true;
+	if ( enabled && m_showFormatToolbar )
 		toolBar( "formatToolBar" )->show();
 	else
 		toolBar( "formatToolBar" )->hide();
+	adjustingFormatToolbar = false;
 	updateSpellCheckAction();
 }
 
+void KopeteChatWindow::slotAutoSpellCheckEnabled( ChatView* view, bool isEnabled )
+{
+	if ( view != m_activeView )
+		return;
+
+	toggleAutoSpellCheck->setEnabled( isEnabled );
+	toggleAutoSpellCheck->setChecked( isEnabled );
+	m_activeView->editPart()->toggleAutoSpellCheck( isEnabled );
+}
+
 bool KopeteChatWindow::queryClose()
 {
 	bool canClose = true;
@@ -1122,7 +1165,7 @@ bool KopeteChatWindow::queryExit()
 		Kopete::PluginManager::self()->shutdown();
 		return true;
 	}
-	else 
+	else
 		return false;
 }
 
@@ -1137,7 +1180,7 @@ void KopeteChatWindow::closeEvent( QCloseEvent * e )
 		// Save settings if auto-save is enabled, and settings have changed
 		if ( settingsDirty() && autoSaveSettings() )
 			saveAutoSaveSettings();
-	
+
 		if ( queryClose() ) {
 			e->accept();
 		}
@@ -1162,8 +1205,8 @@ void KopeteChatWindow::slotConfKeys()
 			++it;
 		}
 
-		if( m_activeView->part() )
-			dlg.insert( m_activeView->part()->actionCollection(), m_activeView->part()->name() );
+		if( m_activeView->editPart() )
+			dlg.insert( m_activeView->editPart()->actionCollection(), m_activeView->editPart()->name() );
 	}
 
 	dlg.configure();
@@ -1176,10 +1219,7 @@ void KopeteChatWindow::slotConfToolbar()
 	if (dlg->exec())
 	{
 		if( m_activeView )
-		{
-			createGUI( m_activeView->part() );
-			//guiFactory()->addClient(m_activeView->msgManager());
-		}
+			createGUI( m_activeView->editPart() );
 		else
 			createGUI( 0L );
 		applyMainWindowSettings(KGlobal::config(), QString::fromLatin1( "KopeteChatWindow" ));
