@@ -3,7 +3,7 @@
                              -------------------
     begin                : lun oct 28 2002
     copyright            : (C) 2002 by Olivier Goffart
-    email                : ogoffart@tiscalinet.be
+    email                : ogoffart @ kde.org
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,8 +21,8 @@
 #include "kopetelistviewitem.h"
 #include <qpixmap.h>
 
-#define KOPETE_GROUP_DEFAULT_OPEN_ICON "folder_green_open"
-#define KOPETE_GROUP_DEFAULT_CLOSED_ICON "folder_green"
+#define KOPETE_GROUP_DEFAULT_OPEN_ICON "folder_open"
+#define KOPETE_GROUP_DEFAULT_CLOSED_ICON "folder"
 
 namespace Kopete
 {
