@@ -26,6 +26,9 @@
 #include "videoinput.h"
 #include "videodevice.h"
 
+#include "bayer.h"
+#include "sonix_compress.h"
+
 #define CLEAR(x) memset (&(x), 0, sizeof (x))
 
 namespace Kopete {
@@ -39,6 +42,10 @@ VideoDevice::VideoDevice()
 	m_streambuffers  = 0;
 	m_current_input = 0;
 //	kdDebug(14010) << "libkopete (avdevice): VideoDevice() exited successfuly" << endl;
+	maxwidth  = 32767;
+	maxheight = 32767;
+	minwidth  = 1;
+	minheight = 1;
 }
 
 
@@ -280,7 +287,6 @@ CLEAR (queryctrl);
 // http://www.linuxtv.org/downloads/video4linux/API/V4L2_API/spec/x519.htm fails because of this behavior with a bttv card.
 
 int currentid = V4L2_CID_BASE;
-int resultado = 0;
 
 kdDebug(14010) <<  k_funcinfo << "Checking CID controls" << endl;
 
@@ -299,7 +305,7 @@ kdDebug(14010) <<  k_funcinfo << " Control: " << QString::fromLocal8Bit((const c
 
 /*		switch (queryctrl.type)
 		{
-			case V4L2_CTRL_TYPE_INTEGER : 
+			case V4L2_CTRL_TYPE_INTEGER :
 		}*/
 		if (queryctrl.type == V4L2_CTRL_TYPE_MENU)
 			enumerateMenu ();
@@ -376,7 +382,7 @@ kdDebug(14010) <<  k_funcinfo << " Control: " << QString::fromLocal8Bit((const c
 				if(V4L_capabilities.type & VID_TYPE_CHROMAKEY)
 					m_videochromakey=true;
 				if(V4L_capabilities.type & VID_TYPE_SCALES)
-					m_videoscale=true;	
+					m_videoscale=true;
 				if(V4L_capabilities.type & VID_TYPE_OVERLAY)
 					m_videooverlay=true;
 //				kdDebug(14010) << "libkopete (avdevice):     Inputs : " << V4L_capabilities.channels << endl;
@@ -420,37 +426,8 @@ kdDebug(14010) <<  k_funcinfo << " Control: " << QString::fromLocal8Bit((const c
 		}
 #endif
 		m_name=m_model; // Take care about changing the name to be different from the model itself...
-// TODO: THis thing can be used to detec what pixel formats are supported in a API-independent way, but V4L2 has VIDIOC_ENUM_PIXFMT.
-// The correct thing to do is to isolate these calls and do a proper implementation for V4L and another for V4L2 when this thing will be migrated to a plugin architecture.
-		kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << "Supported pixel formats:" << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_GREY))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_GREY) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB332))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_RGB332) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB555))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_RGB555) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB555X))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_RGB555X) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB565))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_RGB565) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB565X))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_RGB565X) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB24))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_RGB24) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_BGR24))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_BGR24) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB32))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_RGB32) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_BGR32))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_BGR32) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_YUYV))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_YUYV) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_UYVY))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_UYVY) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_YUV422P))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_YUV422P) << endl;
-		if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_YUV420P))
-			kdDebug(14010) <<  k_funcinfo << "checkDevice(): " << pixelFormatName(PIXELFORMAT_YUV420P) << endl;
+
+		detectPixelFormats();
 
 // TODO: Now we must execute the proper initialization according to the type of the driver.
 		kdDebug(14010) <<  k_funcinfo << "checkDevice() exited successfuly." << endl;
@@ -670,7 +647,15 @@ kdDebug(14010) <<  k_funcinfo << "setSize(" << newwidth << ", " << newheight <<
 								{
 									kdDebug(14010) <<  k_funcinfo << "Card doesn't seem to support RGB32 format. Trying BGR32." << endl;
 									if(PIXELFORMAT_NONE == setPixelFormat(PIXELFORMAT_BGR32))
-										kdDebug(14010) <<  k_funcinfo << "Card doesn't seem to support BGR32 format. Fallback to it is not yet implemented." << endl;
+									{
+										kdDebug(14010) <<  k_funcinfo << "Card doesn't seem to support BGR32 format. Trying SN9C10X." << endl;
+										if(PIXELFORMAT_NONE == setPixelFormat(PIXELFORMAT_SN9C10X))
+										{
+											kdDebug(14010) <<  k_funcinfo << "Card doesn't seem to support SN9C10X format. Trying Bayer RGB." << endl;
+											if(PIXELFORMAT_NONE == setPixelFormat(PIXELFORMAT_SBGGR8))
+												kdDebug(14010) <<  k_funcinfo << "Card doesn't seem to support SBGGR8 format. Fallback from it is not yet implemented." << endl;
+										}
+									}
 								}
 							}
 						}
@@ -804,7 +789,7 @@ pixel_format VideoDevice::setPixelFormat(pixel_format newformat)
 			}
 			else
 				m_pixelformat = pixelFormatForPalette(fmt.fmt.pix.pixelformat);
-		
+
 			fmt.fmt.pix.pixelformat = pixelFormatCode(newformat);
 			if (-1 == xioctl (VIDIOC_S_FMT, &fmt))
 			{
@@ -812,8 +797,11 @@ pixel_format VideoDevice::setPixelFormat(pixel_format newformat)
 			}
 			else
 			{
-				m_pixelformat = newformat;
-				ret = m_pixelformat;
+				if (fmt.fmt.pix.pixelformat == pixelFormatCode(newformat))
+				{
+					m_pixelformat = newformat;
+					ret = m_pixelformat;
+				}
 			}
 			break;
 #endif
@@ -1132,7 +1120,7 @@ memcpy(&m_currentbuffer.data[0], m_rawbuffers[v4l2buffer.index].start, m_current
 				break;
 		}
 
-// Automatic color correction. Now it just swaps R and B channels in RGB24/BGR24 modes.
+/* Automatic color correction. Now it just swaps R and B channels in RGB24/BGR24 modes.
 		if(m_input[m_current_input].getAutoColorCorrection())
 		{
 			switch(m_currentbuffer.pixelformat)
@@ -1173,7 +1161,7 @@ memcpy(&m_currentbuffer.data[0], m_rawbuffers[v4l2buffer.index].start, m_current
 				case PIXELFORMAT_YUV420P: break;
 				case PIXELFORMAT_YUV422P: break;
 			}
-		}
+		}*/
 //kdDebug(14010) <<  k_funcinfo << "10 Using IO_METHOD_READ.File descriptor: " << descriptor << " Buffer address: " << &m_currentbuffer.data[0] << " Size: " << m_currentbuffer.data.size() << endl;
 
 
@@ -1208,16 +1196,20 @@ int VideoDevice::getImage(QImage *qimage)
 {
     /// @todo implement me
 
-	qimage->create(width(), height(),32, QImage::IgnoreEndian);
+	// do NOT delete qimage here, as it is received as a parameter
+	if (qimage->width() != width() || qimage->height() != height())
+		qimage->create(width(), height(),32, QImage::IgnoreEndian);
+
 	uchar *bits=qimage->bits();
-//kdDebug(14010) <<  k_funcinfo << "Capturing in " << pixelFormatName(m_currentbuffer.pixelformat) << endl;
+// kDebug() << "Capturing in " << pixelFormatName(m_currentbuffer.pixelformat);
 	switch(m_currentbuffer.pixelformat)
 	{
 		case PIXELFORMAT_NONE	: break;
-		case PIXELFORMAT_GREY	: break;
+
+// Packed RGB formats
 		case PIXELFORMAT_RGB332	: break;
+		case PIXELFORMAT_RGB444	: break;
 		case PIXELFORMAT_RGB555	: break;
-		case PIXELFORMAT_RGB555X: break;
 		case PIXELFORMAT_RGB565	:
 			{
 				int step=0;
@@ -1231,7 +1223,21 @@ int VideoDevice::getImage(QImage *qimage)
 				}
 			}
 			break;
+		case PIXELFORMAT_RGB555X: break;
 		case PIXELFORMAT_RGB565X: break;
+		case PIXELFORMAT_BGR24	:
+			{
+				int step=0;
+				for(int loop=0;loop < qimage->numBytes();loop+=4)
+				{
+					bits[loop]   = m_currentbuffer.data[step+2];
+					bits[loop+1] = m_currentbuffer.data[step+1];
+					bits[loop+2] = m_currentbuffer.data[step];
+					bits[loop+3] = 255;
+					step+=3;
+				}
+			}
+			break;
 		case PIXELFORMAT_RGB24	:
 			{
 				int step=0;
@@ -1245,27 +1251,34 @@ int VideoDevice::getImage(QImage *qimage)
 				}
 			}
 			break;
-		case PIXELFORMAT_BGR24	: break;
-			{
-				int step=0;
-				for(int loop=0;loop < qimage->numBytes();loop+=4)
-				{
-					bits[loop]   = m_currentbuffer.data[step+2];
-					bits[loop+1] = m_currentbuffer.data[step+1];
-					bits[loop+2] = m_currentbuffer.data[step];
-					bits[loop+3] = 255;
-					step+=3;
-				}
-			}
-			break;
+		case PIXELFORMAT_BGR32	: break;
 		case PIXELFORMAT_RGB32	: memcpy(bits,&m_currentbuffer.data[0], m_currentbuffer.data.size());
 			break;
-		case PIXELFORMAT_BGR32	: break;
-	
+
+// Bayer RGB format
+		case PIXELFORMAT_SBGGR8	:
+		{
+			unsigned char *d = (unsigned char *) malloc (width() * height() * 3);
+			bayer2rgb24(d, &m_currentbuffer.data.first(), width(), height());
+			int step=0;
+			for(int loop=0;loop < qimage->numBytes();loop+=4)
+			{
+				bits[loop]   = d[step+2];
+				bits[loop+1] = d[step+1];
+				bits[loop+2] = d[step];
+				bits[loop+3] = 255;
+				step+=3;
+			}
+			free(d);
+		}
+		break;
+
+// YUV formats
+		case PIXELFORMAT_GREY	: break;
 		case PIXELFORMAT_YUYV:
 		case PIXELFORMAT_UYVY:
-		case PIXELFORMAT_YUV422P:
 		case PIXELFORMAT_YUV420P:
+		case PIXELFORMAT_YUV422P:
 		{
 			uchar *yptr, *cbptr, *crptr;
 			bool halfheight=false;
@@ -1293,7 +1306,7 @@ int VideoDevice::getImage(QImage *qimage)
 				cbptr = yptr + (width()*height());
 				crptr = cbptr + (width()*height()/(halfheight ? 4:2));
 			}
-	
+
 			for(int y=0; y<height(); y++)
 			{
 // Decode scanline
@@ -1313,18 +1326,18 @@ int VideoDevice::getImage(QImage *qimage)
 						d = (cbptr[x>>1])-128;
 						e = (crptr[x>>1])-128;
 					}
-	
+
 					int r = (298 * c           + 409 * e + 128)>>8;
 					int g = (298 * c - 100 * d - 208 * e + 128)>>8;
 					int b = (298 * c + 516 * d           + 128)>>8;
-	
+
 					if (r<0) r=0;   if (r>255) r=255;
 					if (g<0) g=0;   if (g>255) g=255;
 					if (b<0) b=0;   if (b>255) b=255;
-	
+
 					uint *p = (uint*)qimage->scanLine(y)+x;
 					*p = qRgba(r,g,b,255);
-	
+
 				}
 // Jump to next line
 				if (packed)
@@ -1345,8 +1358,42 @@ int VideoDevice::getImage(QImage *qimage)
 			}
 		}
 		break;
-	}
 
+// Compressed formats
+		case PIXELFORMAT_JPEG	: break;
+		case PIXELFORMAT_MPEG	: break;
+
+// Reserved formats
+		case PIXELFORMAT_DV	: break;
+		case PIXELFORMAT_ET61X251:break;
+		case PIXELFORMAT_HI240	: break;
+		case PIXELFORMAT_HM12	: break;
+		case PIXELFORMAT_MJPEG	: break;
+		case PIXELFORMAT_PWC1	: break;
+		case PIXELFORMAT_PWC2	: break;
+		case PIXELFORMAT_SN9C10X:
+		{
+			unsigned char *s = new unsigned char [width() * height()];
+			unsigned char *d = new unsigned char [width() * height() * 3];
+			sonix_decompress_init();
+			sonix_decompress(width(), height(), &m_currentbuffer.data.first(), s);
+			bayer2rgb24(d, s, width(), height());
+			int step=0;
+			for(int loop=0;loop < qimage->numBytes();loop+=4)
+			{
+				bits[loop]   = d[step+2];
+				bits[loop+1] = d[step+1];
+				bits[loop+2] = d[step];
+				bits[loop+3] = 255;
+				step+=3;
+			}
+			delete[] s;
+			delete[] d;
+		}
+		break;
+		case PIXELFORMAT_WNVA	: break;
+		case PIXELFORMAT_YYUV	: break;
+	}
 	return EXIT_SUCCESS;
 }
 
@@ -1455,7 +1502,7 @@ float VideoDevice::setBrightness(float brightness)
 				{
 					CLEAR (control);
 					control.id = V4L2_CID_BRIGHTNESS;
-					control.value = (queryctrl.maximum - queryctrl.minimum)*getBrightness();
+					control.value = (__s32)((queryctrl.maximum - queryctrl.minimum)*getBrightness());
 
 					if (-1 == xioctl (VIDIOC_S_CTRL, &control))
 					{
@@ -1470,7 +1517,7 @@ float VideoDevice::setBrightness(float brightness)
 				struct video_picture V4L_picture;
 				if(-1 == xioctl(VIDIOCGPICT, &V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "VIDIOCGPICT failed (" << errno << ")." << endl;
-				V4L_picture.brightness   = (65535*getBrightness());
+				V4L_picture.brightness   = uint(65535*getBrightness());
 				if(-1 == xioctl(VIDIOCSPICT,&V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "Card seems to not support adjusting image brightness. Fallback to it is not yet implemented." << endl;
 			}
@@ -1525,7 +1572,7 @@ float VideoDevice::setContrast(float contrast)
 				{
 					CLEAR (control);
 					control.id = V4L2_CID_CONTRAST;
-					control.value = (queryctrl.maximum - queryctrl.minimum)*getContrast();
+					control.value = (__s32)((queryctrl.maximum - queryctrl.minimum)*getContrast());
 
 					if (-1 == xioctl (VIDIOC_S_CTRL, &control))
 					{
@@ -1540,7 +1587,7 @@ float VideoDevice::setContrast(float contrast)
 				struct video_picture V4L_picture;
 				if(-1 == xioctl(VIDIOCGPICT, &V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "VIDIOCGPICT failed (" << errno << ")." << endl;
-				V4L_picture.contrast   = (65535*getContrast());
+				V4L_picture.contrast   = uint(65535*getContrast());
 				if(-1 == xioctl(VIDIOCSPICT,&V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "Card seems to not support adjusting image contrast. Fallback to it is not yet implemented." << endl;
 			}
@@ -1595,7 +1642,7 @@ float VideoDevice::setSaturation(float saturation)
 				{
 					CLEAR (control);
 					control.id = V4L2_CID_SATURATION;
-					control.value = (queryctrl.maximum - queryctrl.minimum)*getSaturation();
+					control.value = (__s32)((queryctrl.maximum - queryctrl.minimum)*getSaturation());
 
 					if (-1 == xioctl (VIDIOC_S_CTRL, &control))
 					{
@@ -1610,7 +1657,7 @@ float VideoDevice::setSaturation(float saturation)
 				struct video_picture V4L_picture;
 				if(-1 == xioctl(VIDIOCGPICT, &V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "VIDIOCGPICT failed (" << errno << ")." << endl;
-				V4L_picture.colour   = (65535*getSaturation());
+				V4L_picture.colour   = uint(65535*getSaturation());
 				if(-1 == xioctl(VIDIOCSPICT,&V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "Card seems to not support adjusting image saturation. Fallback to it is not yet implemented." << endl;
 			}
@@ -1665,7 +1712,7 @@ float VideoDevice::setWhiteness(float whiteness)
 				{
 					CLEAR (control);
 					control.id = V4L2_CID_WHITENESS;
-					control.value = (queryctrl.maximum - queryctrl.minimum)*getWhiteness();
+					control.value = (__s32)((queryctrl.maximum - queryctrl.minimum)*getWhiteness());
 
 					if (-1 == xioctl (VIDIOC_S_CTRL, &control))
 					{
@@ -1680,7 +1727,7 @@ float VideoDevice::setWhiteness(float whiteness)
 				struct video_picture V4L_picture;
 				if(-1 == xioctl(VIDIOCGPICT, &V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "VIDIOCGPICT failed (" << errno << ")." << endl;
-				V4L_picture.whiteness   = (65535*getWhiteness());
+				V4L_picture.whiteness   = uint(65535*getWhiteness());
 				if(-1 == xioctl(VIDIOCSPICT,&V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "Card seems to not support adjusting white level. Fallback to it is not yet implemented." << endl;
 			}
@@ -1735,7 +1782,7 @@ float VideoDevice::setHue(float hue)
 				{
 					CLEAR (control);
 					control.id = V4L2_CID_HUE;
-					control.value = (queryctrl.maximum - queryctrl.minimum)*getHue();
+					control.value = (__s32)((queryctrl.maximum - queryctrl.minimum)*getHue());
 
 					if (-1 == xioctl (VIDIOC_S_CTRL, &control))
 					{
@@ -1750,7 +1797,7 @@ float VideoDevice::setHue(float hue)
 				struct video_picture V4L_picture;
 				if(-1 == xioctl(VIDIOCGPICT, &V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "VIDIOCGPICT failed (" << errno << ")." << endl;
-				V4L_picture.hue   = (65535*getHue());
+				V4L_picture.hue   = uint(65535*getHue());
 				if(-1 == xioctl(VIDIOCSPICT,&V4L_picture))
 					kdDebug(14010) <<  k_funcinfo << "Card seems to not support adjusting image hue. Fallback to it is not yet implemented." << endl;
 			}
@@ -1775,14 +1822,14 @@ bool VideoDevice::getAutoBrightnessContrast()
 bool VideoDevice::setAutoBrightnessContrast(bool brightnesscontrast)
 {
 	kdDebug(14010) <<  k_funcinfo << "VideoDevice::setAutoBrightnessContrast(" << brightnesscontrast << ") called." << endl;
-	if (m_current_input < m_input.size() ) 
+	if (m_current_input < m_input.size() )
 	  {
 		m_input[m_current_input].setAutoBrightnessContrast(brightnesscontrast);
 		return m_input[m_current_input].getAutoBrightnessContrast();
 	  }
 	else
 	  return false;
-   
+
 }
 
 bool VideoDevice::getAutoColorCorrection()
@@ -1816,7 +1863,7 @@ bool VideoDevice::getImageAsMirror()
 bool VideoDevice::setImageAsMirror(bool imageasmirror)
 {
 	kdDebug(14010) <<  k_funcinfo << "VideoDevice::setImageAsMirror(" << imageasmirror << ") called." << endl;
-	if (m_current_input < m_input.size() ) 
+	if (m_current_input < m_input.size() )
 	  {
 		m_input[m_current_input].setImageAsMirror(imageasmirror);
 		return m_input[m_current_input].getImageAsMirror();
@@ -1825,30 +1872,6 @@ bool VideoDevice::setImageAsMirror(bool imageasmirror)
 	  return false;
 }
 
-bool VideoDevice::getDisableMMap()
-{
-	return m_disablemmap;
-}
-
-bool VideoDevice::setDisableMMap(bool disablemmap)
-{
-	kdDebug(14010) <<  k_funcinfo << "VideoDevice::setDisableMMap(" << disablemmap << ") called." << endl;
-	m_disablemmap = disablemmap;
-	return m_disablemmap;
-}
-
-bool VideoDevice::getWorkaroundBrokenDriver()
-{
-	return m_workaroundbrokendriver;
-}
-
-bool VideoDevice::setWorkaroundBrokenDriver(bool workaroundbrokendriver)
-{
-	kdDebug(14010) <<  k_funcinfo << "VideoDevice::setWorkaroundBrokenDriver(" << workaroundbrokendriver << ") called." << endl;
-	m_workaroundbrokendriver = workaroundbrokendriver;
-	return m_workaroundbrokendriver;
-}
-
 pixel_format VideoDevice::pixelFormatForPalette( int palette )
 {
 	switch(m_driver)
@@ -1859,20 +1882,48 @@ pixel_format VideoDevice::pixelFormatForPalette( int palette )
 			switch(palette)
 			{
 				case 0 				: return PIXELFORMAT_NONE;	break;
-				case V4L2_PIX_FMT_GREY		: return PIXELFORMAT_GREY;	break;
+
+// Packed RGB formats
 				case V4L2_PIX_FMT_RGB332	: return PIXELFORMAT_RGB332;	break;
+#if defined( V4L2_PIX_FMT_RGB444 )
+				case V4L2_PIX_FMT_RGB444	: return PIXELFORMAT_RGB444;	break;
+#endif
 				case V4L2_PIX_FMT_RGB555	: return PIXELFORMAT_RGB555;	break;
-				case V4L2_PIX_FMT_RGB555X	: return PIXELFORMAT_RGB555X;	break;
 				case V4L2_PIX_FMT_RGB565	: return PIXELFORMAT_RGB565;	break;
+				case V4L2_PIX_FMT_RGB555X	: return PIXELFORMAT_RGB555X;	break;
 				case V4L2_PIX_FMT_RGB565X	: return PIXELFORMAT_RGB565X;	break;
-				case V4L2_PIX_FMT_RGB24		: return PIXELFORMAT_RGB24;	break;
 				case V4L2_PIX_FMT_BGR24		: return PIXELFORMAT_BGR24;	break;
-				case V4L2_PIX_FMT_RGB32		: return PIXELFORMAT_RGB32;	break;
+				case V4L2_PIX_FMT_RGB24		: return PIXELFORMAT_RGB24;	break;
 				case V4L2_PIX_FMT_BGR32		: return PIXELFORMAT_BGR32;	break;
+				case V4L2_PIX_FMT_RGB32		: return PIXELFORMAT_RGB32;	break;
+
+// Bayer RGB format
+				case V4L2_PIX_FMT_SBGGR8	: return PIXELFORMAT_SBGGR8;	break;
+
+// YUV formats
+				case V4L2_PIX_FMT_GREY		: return PIXELFORMAT_GREY;	break;
 				case V4L2_PIX_FMT_YUYV		: return PIXELFORMAT_YUYV;	break;
 				case V4L2_PIX_FMT_UYVY		: return PIXELFORMAT_UYVY;	break;
 				case V4L2_PIX_FMT_YUV420	: return PIXELFORMAT_YUV420P;	break;
 				case V4L2_PIX_FMT_YUV422P	: return PIXELFORMAT_YUV422P;	break;
+
+// Compressed formats
+				case V4L2_PIX_FMT_JPEG		: return PIXELFORMAT_JPEG;	break;
+				case V4L2_PIX_FMT_MPEG		: return PIXELFORMAT_MPEG;	break;
+
+// Reserved formats
+				case V4L2_PIX_FMT_DV		: return PIXELFORMAT_DV;	break;
+				case V4L2_PIX_FMT_ET61X251	: return PIXELFORMAT_ET61X251;	break;
+				case V4L2_PIX_FMT_HI240		: return PIXELFORMAT_HI240;	break;
+#if defined( V4L2_PIX_FMT_HM12 )
+				case V4L2_PIX_FMT_HM12		: return PIXELFORMAT_HM12;	break;
+#endif
+				case V4L2_PIX_FMT_MJPEG		: return PIXELFORMAT_MJPEG;	break;
+				case V4L2_PIX_FMT_PWC1		: return PIXELFORMAT_PWC1;	break;
+				case V4L2_PIX_FMT_PWC2		: return PIXELFORMAT_PWC2;	break;
+				case V4L2_PIX_FMT_SN9C10X	: return PIXELFORMAT_SN9C10X;	break;
+				case V4L2_PIX_FMT_WNVA		: return PIXELFORMAT_WNVA;	break;
+				case V4L2_PIX_FMT_YYUV		: return PIXELFORMAT_YYUV;	break;
 			}
 			break;
 #endif
@@ -1911,20 +1962,48 @@ int VideoDevice::pixelFormatCode(pixel_format pixelformat)
 			switch(pixelformat)
 			{
 				case PIXELFORMAT_NONE	: return 0;			break;
-				case PIXELFORMAT_GREY	: return V4L2_PIX_FMT_GREY;	break;
+
+// Packed RGB formats
 				case PIXELFORMAT_RGB332	: return V4L2_PIX_FMT_RGB332;	break;
+#if defined( V4L2_PIX_FMT_RGB44 )
+				case PIXELFORMAT_RGB444	: return V4L2_PIX_FMT_RGB444;	break;
+#endif
 				case PIXELFORMAT_RGB555	: return V4L2_PIX_FMT_RGB555;	break;
-				case PIXELFORMAT_RGB555X: return V4L2_PIX_FMT_RGB555X;	break;
 				case PIXELFORMAT_RGB565	: return V4L2_PIX_FMT_RGB565;	break;
+				case PIXELFORMAT_RGB555X: return V4L2_PIX_FMT_RGB555X;	break;
 				case PIXELFORMAT_RGB565X: return V4L2_PIX_FMT_RGB565X;	break;
-				case PIXELFORMAT_RGB24	: return V4L2_PIX_FMT_RGB24;	break;
 				case PIXELFORMAT_BGR24	: return V4L2_PIX_FMT_BGR24;	break;
-				case PIXELFORMAT_RGB32	: return V4L2_PIX_FMT_RGB32;	break;
+				case PIXELFORMAT_RGB24	: return V4L2_PIX_FMT_RGB24;	break;
 				case PIXELFORMAT_BGR32	: return V4L2_PIX_FMT_BGR32;	break;
+				case PIXELFORMAT_RGB32	: return V4L2_PIX_FMT_RGB32;	break;
+
+// Bayer RGB format
+				case PIXELFORMAT_SBGGR8	: return V4L2_PIX_FMT_SBGGR8;	break;
+
+// YUV formats
+				case PIXELFORMAT_GREY	: return V4L2_PIX_FMT_GREY;	break;
 				case PIXELFORMAT_YUYV	: return V4L2_PIX_FMT_YUYV;	break;
 				case PIXELFORMAT_UYVY	: return V4L2_PIX_FMT_UYVY;	break;
 				case PIXELFORMAT_YUV420P: return V4L2_PIX_FMT_YUV420;	break;
 				case PIXELFORMAT_YUV422P: return V4L2_PIX_FMT_YUV422P;	break;
+
+// Compressed formats
+				case PIXELFORMAT_JPEG	: return V4L2_PIX_FMT_JPEG;	break;
+				case PIXELFORMAT_MPEG	: return V4L2_PIX_FMT_MPEG;	break;
+
+// Reserved formats
+				case PIXELFORMAT_DV	: return V4L2_PIX_FMT_DV;	break;
+				case PIXELFORMAT_ET61X251:return V4L2_PIX_FMT_ET61X251;break;
+				case PIXELFORMAT_HI240	: return V4L2_PIX_FMT_HI240;	break;
+#if defined( V4L2_PIX_FMT_HM12 )
+				case PIXELFORMAT_HM12	: return V4L2_PIX_FMT_HM12;	break;
+#endif
+				case PIXELFORMAT_MJPEG	: return V4L2_PIX_FMT_MJPEG;	break;
+				case PIXELFORMAT_PWC1	: return V4L2_PIX_FMT_PWC1;	break;
+				case PIXELFORMAT_PWC2	: return V4L2_PIX_FMT_PWC2;	break;
+				case PIXELFORMAT_SN9C10X: return V4L2_PIX_FMT_SN9C10X;	break;
+				case PIXELFORMAT_WNVA	: return V4L2_PIX_FMT_WNVA;	break;
+				case PIXELFORMAT_YYUV	: return V4L2_PIX_FMT_YYUV;	break;
 			}
 			break;
 #endif
@@ -1932,20 +2011,44 @@ int VideoDevice::pixelFormatCode(pixel_format pixelformat)
 			switch(pixelformat)
 			{
 				case PIXELFORMAT_NONE	: return 0;			break;
-				case PIXELFORMAT_GREY	: return VIDEO_PALETTE_GREY;	break;
+
+// Packed RGB formats
 				case PIXELFORMAT_RGB332	: return VIDEO_PALETTE_HI240;	break;
+				case PIXELFORMAT_RGB444	: return 0;			break;
 				case PIXELFORMAT_RGB555	: return VIDEO_PALETTE_RGB555;	break;
-				case PIXELFORMAT_RGB555X: return PIXELFORMAT_NONE;	break;
 				case PIXELFORMAT_RGB565	: return VIDEO_PALETTE_RGB565;	break;
-				case PIXELFORMAT_RGB565X: return PIXELFORMAT_NONE;	break;
+				case PIXELFORMAT_RGB555X: return 0;			break;
+				case PIXELFORMAT_RGB565X: return 0;			break;
+				case PIXELFORMAT_BGR24	: return 0;			break;
 				case PIXELFORMAT_RGB24	: return VIDEO_PALETTE_RGB24;	break;
-				case PIXELFORMAT_BGR24	: return PIXELFORMAT_NONE;	break;
+				case PIXELFORMAT_BGR32	: return 0;			break;
 				case PIXELFORMAT_RGB32	: return VIDEO_PALETTE_RGB32;	break;
-				case PIXELFORMAT_BGR32	: return PIXELFORMAT_NONE;	break;
+
+// Bayer RGB format
+				case PIXELFORMAT_SBGGR8	: return 0;			break;
+
+// YUV formats
+				case PIXELFORMAT_GREY	: return VIDEO_PALETTE_GREY;	break;
 				case PIXELFORMAT_YUYV	: return VIDEO_PALETTE_YUYV;	break;
 				case PIXELFORMAT_UYVY	: return VIDEO_PALETTE_UYVY;	break;
 				case PIXELFORMAT_YUV420P: return VIDEO_PALETTE_YUV420;	break;
 				case PIXELFORMAT_YUV422P: return VIDEO_PALETTE_YUV422P;	break;
+
+// Compressed formats
+				case PIXELFORMAT_JPEG	: return 0;			break;
+				case PIXELFORMAT_MPEG	: return 0;			break;
+
+// Reserved formats
+				case PIXELFORMAT_DV	: return 0;			break;
+				case PIXELFORMAT_ET61X251:return 0;			break;
+				case PIXELFORMAT_HI240	: return VIDEO_PALETTE_HI240;	break;
+				case PIXELFORMAT_HM12	: return 0;			break;
+				case PIXELFORMAT_MJPEG	: return 0;			break;
+				case PIXELFORMAT_PWC1	: return 0;			break;
+				case PIXELFORMAT_PWC2	: return 0;			break;
+				case PIXELFORMAT_SN9C10X: return 0;			break;
+				case PIXELFORMAT_WNVA	: return 0;			break;
+				case PIXELFORMAT_YYUV	: return 0;			break;
 			}
 			break;
 #endif
@@ -1961,20 +2064,44 @@ int VideoDevice::pixelFormatDepth(pixel_format pixelformat)
 	switch(pixelformat)
 	{
 		case PIXELFORMAT_NONE	: return 0;	break;
-		case PIXELFORMAT_GREY	: return 8;	break;
+
+// Packed RGB formats
 		case PIXELFORMAT_RGB332	: return 8;	break;
+		case PIXELFORMAT_RGB444	: return 16;	break;
 		case PIXELFORMAT_RGB555	: return 16;	break;
-		case PIXELFORMAT_RGB555X: return 16;	break;
 		case PIXELFORMAT_RGB565	: return 16;	break;
+		case PIXELFORMAT_RGB555X: return 16;	break;
 		case PIXELFORMAT_RGB565X: return 16;	break;
-		case PIXELFORMAT_RGB24	: return 24;	break;
 		case PIXELFORMAT_BGR24	: return 24;	break;
-		case PIXELFORMAT_RGB32	: return 32;	break;
+		case PIXELFORMAT_RGB24	: return 24;	break;
 		case PIXELFORMAT_BGR32	: return 32;	break;
+		case PIXELFORMAT_RGB32	: return 32;	break;
+
+// Bayer RGB format
+		case PIXELFORMAT_SBGGR8	: return 0;	break;
+
+// YUV formats
+		case PIXELFORMAT_GREY	: return 8;	break;
 		case PIXELFORMAT_YUYV	: return 16;	break;
 		case PIXELFORMAT_UYVY	: return 16;	break;
 		case PIXELFORMAT_YUV420P: return 16;	break;
 		case PIXELFORMAT_YUV422P: return 16;	break;
+
+// Compressed formats
+		case PIXELFORMAT_JPEG	: return 0;	break;
+		case PIXELFORMAT_MPEG	: return 0;	break;
+
+// Reserved formats
+		case PIXELFORMAT_DV	: return 0;	break;
+		case PIXELFORMAT_ET61X251:return 0;	break;
+		case PIXELFORMAT_HI240	: return 8;	break;
+		case PIXELFORMAT_HM12	: return 0;	break;
+		case PIXELFORMAT_MJPEG	: return 0;	break;
+		case PIXELFORMAT_PWC1	: return 0;	break;
+		case PIXELFORMAT_PWC2	: return 0;	break;
+		case PIXELFORMAT_SN9C10X: return 0;	break;
+		case PIXELFORMAT_WNVA	: return 0;	break;
+		case PIXELFORMAT_YYUV	: return 0;	break;
 	}
 	return 0;
 }
@@ -1986,20 +2113,45 @@ QString VideoDevice::pixelFormatName(pixel_format pixelformat)
 	switch(pixelformat)
 	{
 		case PIXELFORMAT_NONE	: returnvalue = "None";			break;
-		case PIXELFORMAT_GREY	: returnvalue = "8-bit Grayscale";	break;
+
+// Packed RGB formats
 		case PIXELFORMAT_RGB332	: returnvalue = "8-bit RGB332";		break;
+		case PIXELFORMAT_RGB444	: returnvalue = "8-bit RGB444";		break;
 		case PIXELFORMAT_RGB555	: returnvalue = "16-bit RGB555";	break;
-		case PIXELFORMAT_RGB555X: returnvalue = "16-bit RGB555X";	break;
 		case PIXELFORMAT_RGB565	: returnvalue = "16-bit RGB565";	break;
+		case PIXELFORMAT_RGB555X: returnvalue = "16-bit RGB555X";	break;
 		case PIXELFORMAT_RGB565X: returnvalue = "16-bit RGB565X";	break;
-		case PIXELFORMAT_RGB24	: returnvalue = "24-bit RGB24";		break;
 		case PIXELFORMAT_BGR24	: returnvalue = "24-bit BGR24";		break;
-		case PIXELFORMAT_RGB32	: returnvalue = "32-bit RGB32";		break;
+		case PIXELFORMAT_RGB24	: returnvalue = "24-bit RGB24";		break;
 		case PIXELFORMAT_BGR32	: returnvalue = "32-bit BGR32";		break;
+		case PIXELFORMAT_RGB32	: returnvalue = "32-bit RGB32";		break;
+
+// Bayer RGB format
+		case PIXELFORMAT_SBGGR8	: returnvalue = "Bayer RGB format";	break;
+
+// YUV formats
+		case PIXELFORMAT_GREY	: returnvalue = "8-bit Grayscale";	break;
 		case PIXELFORMAT_YUYV	: returnvalue = "Packed YUV 4:2:2";	break;
 		case PIXELFORMAT_UYVY	: returnvalue = "Packed YVU 4:2:2";	break;
 		case PIXELFORMAT_YUV420P: returnvalue = "Planar YUV 4:2:0";	break;
 		case PIXELFORMAT_YUV422P: returnvalue = "Planar YUV 4:2:2";	break;
+
+
+// Compressed formats
+		case PIXELFORMAT_JPEG	: returnvalue = "JPEG image";		break;
+		case PIXELFORMAT_MPEG	: returnvalue = "MPEG stream";		break;
+
+// Reserved formats
+		case PIXELFORMAT_DV	: returnvalue = "DV (unknown)";		break;
+		case PIXELFORMAT_ET61X251:returnvalue = "ET61X251";		break;
+		case PIXELFORMAT_HI240	: returnvalue = "8-bit HI240 (RGB332)";	break;
+		case PIXELFORMAT_HM12	: returnvalue = "Packed YUV 4:2:2";	break;
+		case PIXELFORMAT_MJPEG	: returnvalue = "8-bit Grayscale";	break;
+		case PIXELFORMAT_PWC1	: returnvalue = "PWC1";			break;
+		case PIXELFORMAT_PWC2	: returnvalue = "PWC2";			break;
+		case PIXELFORMAT_SN9C10X: returnvalue = "SN9C102";		break;
+		case PIXELFORMAT_WNVA	: returnvalue = "Winnov Videum";	break;
+		case PIXELFORMAT_YYUV	: returnvalue = "YYUV (unknown)";	break;
 	}
 	return returnvalue;
 }
@@ -2015,20 +2167,49 @@ QString VideoDevice::pixelFormatName(int pixelformat)
 		case VIDEODEV_DRIVER_V4L2:
 			switch(pixelformat)
 			{
-				case V4L2_PIX_FMT_GREY		: returnvalue = pixelFormatName(PIXELFORMAT_GREY);	break;
+				case 0				: returnvalue = pixelFormatName(PIXELFORMAT_NONE);	break;
+
+// Packed RGB formats
 				case V4L2_PIX_FMT_RGB332	: returnvalue = pixelFormatName(PIXELFORMAT_RGB332);	break;
+#if defined( V4L2_PIX_FMT_RGB444 )
+				case V4L2_PIX_FMT_RGB444	: returnvalue = pixelFormatName(PIXELFORMAT_RGB444);	break;
+#endif
 				case V4L2_PIX_FMT_RGB555	: returnvalue = pixelFormatName(PIXELFORMAT_RGB555);	break;
-				case V4L2_PIX_FMT_RGB555X	: returnvalue = pixelFormatName(PIXELFORMAT_RGB555X);	break;
 				case V4L2_PIX_FMT_RGB565	: returnvalue = pixelFormatName(PIXELFORMAT_RGB565);	break;
+				case V4L2_PIX_FMT_RGB555X	: returnvalue = pixelFormatName(PIXELFORMAT_RGB555X);	break;
 				case V4L2_PIX_FMT_RGB565X	: returnvalue = pixelFormatName(PIXELFORMAT_RGB565X);	break;
-				case V4L2_PIX_FMT_RGB24		: returnvalue = pixelFormatName(PIXELFORMAT_RGB24);	break;
 				case V4L2_PIX_FMT_BGR24		: returnvalue = pixelFormatName(PIXELFORMAT_BGR24);	break;
-				case V4L2_PIX_FMT_RGB32		: returnvalue = pixelFormatName(PIXELFORMAT_RGB32);	break;
+				case V4L2_PIX_FMT_RGB24		: returnvalue = pixelFormatName(PIXELFORMAT_RGB24);	break;
 				case V4L2_PIX_FMT_BGR32		: returnvalue = pixelFormatName(PIXELFORMAT_BGR32);	break;
+				case V4L2_PIX_FMT_RGB32		: returnvalue = pixelFormatName(PIXELFORMAT_RGB32);	break;
+
+// Bayer RGB format
+				case V4L2_PIX_FMT_SBGGR8	: returnvalue = pixelFormatName(PIXELFORMAT_SBGGR8);	break;
+
+// YUV formats
+				case V4L2_PIX_FMT_GREY		: returnvalue = pixelFormatName(PIXELFORMAT_GREY);	break;
 				case V4L2_PIX_FMT_YUYV		: returnvalue = pixelFormatName(PIXELFORMAT_YUYV);	break;
 				case V4L2_PIX_FMT_UYVY		: returnvalue = pixelFormatName(PIXELFORMAT_UYVY);	break;
 				case V4L2_PIX_FMT_YUV420	: returnvalue = pixelFormatName(PIXELFORMAT_YUV420P);	break;
 				case V4L2_PIX_FMT_YUV422P	: returnvalue = pixelFormatName(PIXELFORMAT_YUV422P);	break;
+
+// Compressed formats
+				case V4L2_PIX_FMT_JPEG		: returnvalue = pixelFormatName(PIXELFORMAT_JPEG);	break;
+				case V4L2_PIX_FMT_MPEG		: returnvalue = pixelFormatName(PIXELFORMAT_MPEG);	break;
+
+// Reserved formats
+				case V4L2_PIX_FMT_DV		: returnvalue = pixelFormatName(PIXELFORMAT_DV);	break;
+				case V4L2_PIX_FMT_ET61X251	: returnvalue = pixelFormatName(PIXELFORMAT_ET61X251);	break;
+				case V4L2_PIX_FMT_HI240		: returnvalue = pixelFormatName(PIXELFORMAT_HI240);	break;
+#if defined( V4L2_PIX_FMT_HM12 )
+				case V4L2_PIX_FMT_HM12		: returnvalue = pixelFormatName(PIXELFORMAT_HM12);	break;
+#endif
+				case V4L2_PIX_FMT_MJPEG		: returnvalue = pixelFormatName(PIXELFORMAT_MJPEG);	break;
+				case V4L2_PIX_FMT_PWC1		: returnvalue = pixelFormatName(PIXELFORMAT_PWC1);	break;
+				case V4L2_PIX_FMT_PWC2		: returnvalue = pixelFormatName(PIXELFORMAT_PWC2);	break;
+				case V4L2_PIX_FMT_SN9C10X	: returnvalue = pixelFormatName(PIXELFORMAT_SN9C10X);	break;
+				case V4L2_PIX_FMT_WNVA		: returnvalue = pixelFormatName(PIXELFORMAT_WNVA);	break;
+				case V4L2_PIX_FMT_YYUV		: returnvalue = pixelFormatName(PIXELFORMAT_YYUV);	break;
 			}
 			break;
 #endif
@@ -2056,6 +2237,84 @@ QString VideoDevice::pixelFormatName(int pixelformat)
 	return returnvalue;
 }
 
+int VideoDevice::detectPixelFormats()
+{
+			int err = 0;
+	switch(m_driver)
+	{
+#if defined(__linux__) && defined(ENABLE_AV)
+#ifdef V4L2_CAP_VIDEO_CAPTURE
+		case VIDEODEV_DRIVER_V4L2:
+			fmtdesc.index = 0;
+			fmtdesc.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+
+			while ( err == 0 )
+			{
+				if (-1 == xioctl (VIDIOC_ENUM_FMT, &fmtdesc))
+//				if (ioctl(fd, VIDIOC_ENUM_FMT, &fmtdesc) < 0 )
+				{
+					perror("VIDIOC_ENUM_FMT");
+					err = errno;
+				}
+				else
+				{
+					kdDebug(14010) <<  k_funcinfo << fmtdesc.pixelformat << "  " << pixelFormatName(fmtdesc.pixelformat) << endl; // Need a cleanup. PixelFormatForPalette is a really bad name
+					fmtdesc.index++;
+				}
+			}
+//			break;
+#endif
+		case VIDEODEV_DRIVER_V4L:
+// TODO: THis thing can be used to detec what pixel formats are supported in a API-independent way, but V4L2 has VIDIOC_ENUM_PIXFMT.
+// The correct thing to do is to isolate these calls and do a proper implementation for V4L and another for V4L2 when this thing will be migrated to a plugin architecture.
+
+// Packed RGB formats
+			kdDebug(14010) <<  k_funcinfo << "Supported pixel formats:" << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB332))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_RGB332) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB444))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_RGB444) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB555))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_RGB555) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB565))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_RGB565) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB555X))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_RGB555X) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB565X))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_RGB565X) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_BGR24))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_BGR24) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB24))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_RGB24) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_BGR32))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_BGR32) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_RGB32))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_RGB32) << endl;
+
+// Bayer RGB format
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_SBGGR8))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_SBGGR8) << endl;
+
+// YUV formats
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_GREY))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_GREY) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_YUYV))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_YUYV) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_UYVY))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_UYVY) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_YUV420P))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_YUV420P) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_YUV422P))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_YUV422P) << endl;
+
+// Compressed formats
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_JPEG))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_JPEG) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_MPEG))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_MPEG) << endl;
+
+// Reserved formats
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_DV))		kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_DV) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_ET61X251))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_ET61X251) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_HI240))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_HI240) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_HM12))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_HM12) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_MJPEG))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_MJPEG) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_PWC1))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_PWC1) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_PWC2))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_PWC2) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_SN9C10X))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_SN9C10X) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_WNVA))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_WNVA) << endl;
+			if(PIXELFORMAT_NONE != setPixelFormat(PIXELFORMAT_YYUV))	kdDebug(14010) <<  k_funcinfo << pixelFormatName(PIXELFORMAT_YYUV) << endl;
+			break;
+#endif
+		case VIDEODEV_DRIVER_NONE:
+		default:
+			return PIXELFORMAT_NONE;	break;
+	}
+	return PIXELFORMAT_NONE;
+}
+
 __u64 VideoDevice::signalStandardCode(signal_standard standard)
 {
 	switch(m_driver)
