@@ -25,7 +25,7 @@
 #include <kopetecontact.h>
 #include <kopetecontactaction.h>
 #include <kopetemetacontact.h>
-#include <kopetemessagemanagerfactory.h>
+#include <kopetechatsessionmanager.h>
 #include <kopeteprotocol.h>
 #include <kopeteuiglobal.h>
 #include <kopeteview.h>
@@ -68,7 +68,7 @@ GroupWiseChatSession::GroupWiseChatSession(const Kopete::Contact* user, Kopete::
 	m_secure = new KAction( i18n( "Security Status" ), "encrypted", KShortcut(), this, SLOT( slotShowSecurity() ), actionCollection(), "gwSecureChat" );
 	m_secure->setToolTip( i18n( "Conversation is secure" ) );
 	
-	m_logging = new KAction( i18n( "Archiving Status" ), BarIcon( "logging" ), KShortcut(), this, SLOT( slotShowArchiving() ), actionCollection(), "gwLoggingChat" );
+	m_logging = new KAction( i18n( "Archiving Status" ), "logchat", KShortcut(), this, SLOT( slotShowArchiving() ), actionCollection(), "gwLoggingChat" );
 	updateArchiving();
 	
 	setXMLFile("gwchatui.rc");
@@ -199,7 +199,6 @@ void GroupWiseChatSession::slotCreationFailed( const int failedId, const int sta
 		Kopete::Message failureNotify = Kopete::Message( myself(), members(), i18n("An error occurred when trying to start a chat: %1").arg( statusCode ), Kopete::Message::Internal, Kopete::Message::PlainText);
 		appendMessage( failureNotify );
 		setClosed();
-		messageSucceeded();
 	}
 }
 
@@ -361,8 +360,8 @@ void GroupWiseChatSession::slotInviteOtherContact()
 		// show search dialog
 		QWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 
 					Kopete::UI::Global::mainWidget() );
-		m_searchDlg = new KDialogBase( w, "invitesearchdialog", false, i18n( "Search for contact to invite" ), KDialogBase::Ok|KDialogBase::Cancel );
-		m_search = new GroupWiseSearch( account(), QListView::Single, true, m_searchDlg, "invitesearchwidget" );
+		m_searchDlg = new KDialogBase( w, "invitesearchdialog", false, i18n( "Search for Contact to Invite" ), KDialogBase::Ok|KDialogBase::Cancel );
+		m_search = new GroupWiseContactSearch( account(), QListView::Single, true, m_searchDlg, "invitesearchwidget" );
 		m_searchDlg->setMainWidget( m_search );
 		connect( m_search, SIGNAL( selectionValidates( bool ) ), m_searchDlg, SLOT( enableButtonOK( bool ) ) );
 		m_searchDlg->enableButtonOK( false );
