@@ -19,6 +19,8 @@
 
 #include "msnaccount.h"
 
+#include <config.h>
+
 #include <kaction.h>
 #include <kconfig.h>
 #include <kdebug.h>
@@ -45,6 +47,7 @@
 #include "kopeteglobal.h"
 #include "kopetechatsessionmanager.h"
 #include "contactaddednotifydialog.h"
+#include "kopeteutils.h"
 
 #include "sha1.h"
 
@@ -54,6 +57,10 @@
 #include <kglobal.h>
 #endif
 
+#if MSN_WEBCAM
+#include "avdevice/videodevicepool.h"
+#endif
+
 MSNAccount::MSNAccount( MSNProtocol *parent, const QString& AccountID, const char *name )
 	: Kopete::PasswordedAccount ( parent, AccountID.lower(), 0, name )
 {
@@ -103,6 +110,17 @@ MSNAccount::MSNAccount( MSNProtocol *parent, const QString& AccountID, const cha
 		if ( !groupGuid.isEmpty() )
 			m_groupList.insert( groupGuid , g );
 	}
+
+	// Set the client Id for the myself contact.  It sets what MSN feature we support.
+	m_clientId = MSNProtocol::MSNC4 | MSNProtocol::InkFormatGIF | MSNProtocol::SupportMultiPacketMessaging;
+
+#if MSN_WEBCAM
+	Kopete::AV::VideoDevicePool::self()->scanDevices();
+	if( Kopete::AV::VideoDevicePool::self()->hasDevices() )
+	{
+		m_clientId |= MSNProtocol::SupportWebcam;
+	}
+#endif
 }
 
 
@@ -121,6 +139,11 @@ bool MSNAccount::useHttpMethod() const
 	return configGroup()->readBoolEntry(  "useHttpMethod" , false );
 }
 
+QString MSNAccount::myselfClientId() const
+{
+	return QString::number(m_clientId, 10);
+}
+
 void MSNAccount::connectWithPassword( const QString &passwd )
 {
 	m_newContactList=false;
@@ -169,6 +192,7 @@ void MSNAccount::createNotificationServer( const QString &host, uint port )
 		m_notifySocket=0L;
 	}
 
+	m_msgHandle.clear();
 
 	myself()->setOnlineStatus( MSNProtocol::protocol()->CNT );
 
@@ -261,29 +285,44 @@ MSNNotifySocket *MSNAccount::notifySocket()
 
 void MSNAccount::setOnlineStatus( const Kopete::OnlineStatus &status , const QString &reason)
 {
-	// Only update the personal/status message, don't change the online status
-	// since it's the same.
-	if( reason.contains("[Music]") )
-	{
-		QString personalMessage = reason.section("[Music]", 1);
-		setPersonalMessage( MSNProtocol::PersonalMessageMusic, personalMessage );
-	}
-	else
-	{
-		setPersonalMessage( MSNProtocol::PersonalMessageNormal, reason );
+	kdDebug( 14140 ) << k_funcinfo << status.description() << endl;
 
-		if(status.status()== Kopete::OnlineStatus::Offline)
-			disconnect();
-		else if ( m_notifySocket )
+	// HACK: When changing song, do don't anything while connected
+	if( reason.contains("[Music]") && ( status == MSNProtocol::protocol()->UNK || status == MSNProtocol::protocol()->CNT ) )
+		return;
+
+	// Only send personal message when logged.
+	if( m_notifySocket && m_notifySocket->isLogged() )
+	{
+		// Only update the personal/status message, don't change the online status
+		// since it's the same.
+		if( reason.contains("[Music]") )
 		{
-			m_notifySocket->setStatus( status );
+			QString personalMessage = reason.section("[Music]", 1);
+			setPersonalMessage( MSNProtocol::PersonalMessageMusic, personalMessage );
+
+			// Don't send un-needed status change.
+			return;
 		}
 		else
 		{
-			m_connectstatus = status;
-			connect();
+			setPersonalMessage( MSNProtocol::PersonalMessageNormal, reason );
 		}
 	}
+
+	if(status.status()== Kopete::OnlineStatus::Offline)
+		disconnect();
+	else if ( m_notifySocket )
+	{
+		m_notifySocket->setStatus( status );
+	}
+	else
+	{
+		m_connectstatus = status;
+		connect();
+	}
+
+	
 }
 
 void MSNAccount::slotStartChat()
@@ -397,7 +436,7 @@ void MSNAccount::slotNotifySocketClosed()
 			i18n( "Connection Lost - MSN Plugin" ), KMessageBox::Notify );
 	}
 #endif
-
+	m_msgHandle.clear();
 	// kdDebug( 14140 ) << "MSNAccount::slotNotifySocketClosed - done" << endl;
 }
 
@@ -421,10 +460,9 @@ void MSNAccount::slotStatusChanged( const Kopete::OnlineStatus &status )
 					c->setOnlineStatus( MSNProtocol::protocol()->FLN );
 					addContactServerside( c->contactId() , c->metaContact()->groups() );
 				}
-				else //the contact had been deleted, give him the unknown status
+				else //the contact had been deleted, remove it.
 				{
-					c->clearServerGroups();
-					c->setOnlineStatus( MSNProtocol::protocol()->UNK );
+					c->deleteLater();
 				}
 			}
 		}
@@ -990,6 +1028,7 @@ void MSNAccount::slotContactAdded( const QString& handle, const QString& list, c
 
 void MSNAccount::slotContactRemoved( const QString& handle, const QString& list, const QString& contactGuid, const QString& groupGuid )
 {
+	kdDebug( 14140 ) << k_funcinfo << "handle: " << handle << " list: " << list << " contact-uid: " << contactGuid << endl;
 	MSNContact *c=static_cast<MSNContact *>( contacts()[ handle ] );
 	if ( list == "BL" )
 	{
@@ -1038,16 +1077,17 @@ void MSNAccount::slotContactRemoved( const QString& handle, const QString& list,
 	{
 		// The FL list only use the contact GUID, use the contact referenced by the GUID.
 		MSNContact *contactRemoved = findContactByGuid(contactGuid);
-
 		QStringList groupGuidList;
+		bool deleteContact = groupGuid.isEmpty() ? true : false; // Delete the contact when the group GUID is empty.
 		// Remove the contact from the contact list for all the group he is a member.
 		if( groupGuid.isEmpty() )
 		{
 			if(contactRemoved)
 			{
 				QPtrList<Kopete::Group> groupList = contactRemoved->metaContact()->groups();
-				for( Kopete::Group *group = groupList.first(); group; groupList.next() )
+				for( QPtrList<Kopete::Group>::Iterator it = groupList.begin(); it != groupList.end(); ++it )
 				{
+					Kopete::Group *group = *it;
 					if ( !group->pluginData( protocol(), accountId() + " id" ).isEmpty() )
 					{
 						groupGuidList.append( group->pluginData( protocol(), accountId() + " id" ) );
@@ -1089,6 +1129,11 @@ void MSNAccount::slotContactRemoved( const QString& handle, const QString& list,
 				}
 			}
 		}
+		if(deleteContact && contactRemoved)
+		{
+			kdDebug(14140) << k_funcinfo << "Deleting the MSNContact " << contactRemoved->contactId() << endl;
+			contactRemoved->deleteLater();
+		}
 	}
 }
 
@@ -1167,7 +1212,7 @@ void MSNAccount::slotStartChatSession( const QString& handle )
 	{
 		if ( !c->manager(Kopete::Contact::CannotCreate) || !static_cast<MSNChatSession *>( c->manager( Kopete::Contact::CanCreate ) )->service() )
 		{
-			m_msgHandle.append(handle);
+			m_msgHandle.prepend(handle);
 			m_notifySocket->createChatSession();
 		}
 	}
@@ -1214,62 +1259,61 @@ void MSNAccount::slotContactAddedNotifyDialogClosed(const QString& handle)
 
 void MSNAccount::slotGlobalIdentityChanged( const QString &key, const QVariant &value )
 {
-	if(key == Kopete::Global::Properties::self()->nickName().key())
+	if( !configGroup()->readBoolEntry("ExcludeGlobalIdentity", false) )
 	{
-		QString oldNick = myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString();
-		QString newNick = value.toString();
-	
-		if(newNick != oldNick)
+		if(key == Kopete::Global::Properties::self()->nickName().key())
 		{
-			setPublicName( value.toString() );
+			QString oldNick = myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString();
+			QString newNick = value.toString();
+		
+			if(newNick != oldNick)
+			{
+				setPublicName( value.toString() );
+			}
+		}
+		else if(key == Kopete::Global::Properties::self()->photo().key())
+		{
+			m_pictureFilename = value.toString();
+			kdDebug( 14140 ) << k_funcinfo << m_pictureFilename << endl;
+			resetPictureObject(false, true);
 		}
-	}
-	else if(key == Kopete::Global::Properties::self()->photo().key())
-	{
-		m_pictureFilename = value.toString();
-		kdDebug( 14140 ) << k_funcinfo << m_pictureFilename << endl;
-		resetPictureObject(false);
 	}
 }
 
 void MSNAccount::slotErrorMessageReceived( int type, const QString &msg )
 {
-	KMessageBox::DialogType msgBoxType;
 	QString caption = i18n( "MSN Plugin" );
 
+	// Use different notification type based on the error context.
 	switch(type)
 	{
-		case MSNSocket::ErrorNormal:
+		case MSNSocket::ErrorConnectionLost:
 		{
-			msgBoxType = KMessageBox::Error;
+			Kopete::Utils::notifyConnectionLost( this, caption, msg );
 			break;
 		}
-		case MSNSocket::ErrorSorry:
+		case MSNSocket::ErrorConnectionError:
 		{
-			msgBoxType = KMessageBox::Sorry;
+			Kopete::Utils::notifyConnectionError( this, caption, msg );
+			break;
+		}
+		case MSNSocket::ErrorCannotConnect:
+		{
+			Kopete::Utils::notifyCannotConnect( this );
 			break;
 		}
 		case MSNSocket::ErrorInformation:
 		{
-			msgBoxType = KMessageBox::Information;
-			break;
-		}
-		case MSNSocket::ErrorInternal:
-		{
-			msgBoxType = KMessageBox::Information;
-			caption = i18n( "MSN Internal Error" );
+			KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Information, msg, caption );
 			break;
 		}
+		case MSNSocket::ErrorServerError:
 		default:
 		{
-			msgBoxType = KMessageBox::Error;
+			Kopete::Utils::notifyServerError( this, caption, msg );
 			break;
 		}
 	}
-
-	kdDebug(14140) << k_funcinfo << msg << endl;
-	// Display the error
-	KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), msgBoxType, msg, caption );
 }
 
 bool MSNAccount::createContact( const QString &contactId, Kopete::MetaContact *metaContact )
@@ -1344,13 +1388,13 @@ void MSNAccount::addContactServerside(const QString &contactId, QPtrList<Kopete:
 
 MSNContact *MSNAccount::findContactByGuid(const QString &contactGuid)
 {
-	kdDebug(14140) << k_funcinfo << endl;
+	kdDebug(14140) << k_funcinfo << "Looking for " << contactGuid << endl;
 	QDictIterator<Kopete::Contact> it( contacts() );
 	for ( ; it.current(); ++it )
 	{
-		MSNContact *c = static_cast<MSNContact *>( *it );
+		MSNContact *c = dynamic_cast<MSNContact *>( it.current() );
 
-		if(c && c->property( MSNProtocol::protocol()->propGuid ).value().toString() == contactGuid )
+		if(c && c->guid() == contactGuid )
 		{
 			kdDebug(14140) << k_funcinfo << "OK found a contact. " << endl;
 			// Found the contact GUID
@@ -1385,11 +1429,11 @@ QString MSNAccount::pictureObject()
 	return m_pictureObj;
 }
 
-void MSNAccount::resetPictureObject(bool silent)
+void MSNAccount::resetPictureObject(bool silent, bool force)
 {
 	QString old=m_pictureObj;
 
-	if(!configGroup()->readBoolEntry("exportCustomPicture"))
+	if(!configGroup()->readBoolEntry("exportCustomPicture") && !force)
 	{
 		m_pictureObj="";
 		myself()->removeProperty( Kopete::Global::Properties::self()->photo() );
