@@ -2,7 +2,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: opener.cpp 212185 2003-03-07 22:11:39Z waba $
+ * $Id: opener.cpp 764276 2008-01-21 10:42:34Z hasso $
  *
  *              Copyright (C) 1997,98 Bernd Johannes Wuebben,
  *		                      Mario Weilguni
@@ -68,7 +68,11 @@ extern "C" int _Precvmsg(int, void*, int);
 #endif
 
 #ifndef HAVE_NET_IF_PPP_H
-#  ifdef HAVE_LINUX_IF_PPP_H
+#  if defined(__DragonFly__)
+#    include <net/ppp_layer/ppp_defs.h>
+#    include <net/if.h>
+#    include <net/ppp/if_ppp.h>
+#  elif defined HAVE_LINUX_IF_PPP_H
 #    include <linux/if_ppp.h>
 #  endif
 #else
