@@ -1,7 +1,7 @@
 #ifndef SERVERDATATYPE_H
 #define SERVERDATATYPE_H
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 
 class port
@@ -21,23 +21,35 @@ class Server
 {
 
 public:
-  Server( const QString &group, const QString &server, QList<port> ports, 
-          const QString &serverdesc, const QString &script ) {
+    Server( const QString &group,
+	    const QString &server,
+	    QPtrList<port> ports,
+	    const QString &serverdesc,
+	    const QString &script,
+	    const QString &password  = QString::null,
+            bool dossl = false
+	) {
           g=group; s=server; p=ports; sd=serverdesc; sc=script;
-          p.setAutoDelete(TRUE);
+	  pass=password;
+	  ssl = dossl;
+	  p.setAutoDelete(TRUE);
           }
   QString group() const      { return g; }
   QString server() const     { return s; }
-  QList<port> ports() const      { return p; }
+  QPtrList<port> ports() const      { return p; }
   QString serverdesc() const { return sd; }
   QString script() const     { return sc; }
+  QString password() const   { return pass; }
+  bool    usessl() const     { return ssl; }
 
 private:
   QString     g;
   QString     s;
-  QList<port> p;
+  QPtrList<port> p;
   QString     sd;
   QString     sc;
+  QString     pass;
+  bool        ssl;
 
 };
 
