@@ -1,10 +1,7 @@
 #ifndef KBASERULES_H
 #define KBASERULES_H
 
-#include <qstring.h>
-#include <qlist.h>
-
-#include <messageReceiver.h>
+#include "messageReceiver.h"
 
 class KSMBaseRules : public KSircMessageReceiver
 {
@@ -18,7 +15,7 @@ public:
     {
     }
 
-  virtual void sirc_receive(QString str, bool broadcast);
+  virtual void sirc_receive(QCString str, bool broadcast);
 
   virtual void control_message(int, QString);
 
@@ -29,6 +26,10 @@ private:
   char to[101];
   char match_us[101];
   char to_us[101];
+  char msg1_match[101];
+  char msg1_to[101];
+  char msg2_match[101];
+  char msg2_to[101];
 };
 
 #endif
