@@ -18,8 +18,10 @@
 #include <qwidget.h>
 #include <qpainter.h>
 #include <qpixmap.h>
+#include <qlabel.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
+#include <kdebug.h>
 #include "strength.h"
 #include "interface_wireless.h"
 
@@ -40,6 +42,31 @@ Strength::Strength (QWidget * parent, Interface_wireless * device):QWidget (pare
   OOR_DOWN = new QPixmap (kdedir + "oor_down.png");
 }
 
+QSize Strength::mySizeHint () 
+{
+   /* make this quite general, just in case someone uses different icons */
+  QSize* temp = new QSize(NOT_CON_OFFLINE_ADHOC->size());
+  if (EXCELLENT->size().width()  > temp->width ()) { temp->setWidth (EXCELLENT->size().width ()); }
+  if (EXCELLENT->size().height() > temp->height()) { temp->setHeight(EXCELLENT->size().height()); }
+  if (GOOD->size().width()  > temp->width ()) { temp->setWidth (GOOD->size().width ()); }
+  if (GOOD->size().height() > temp->height()) { temp->setHeight(GOOD->size().height()); }
+  if (MARGINAL->size().width()  > temp->width ()) { temp->setWidth (MARGINAL->size().width ()); }
+  if (MARGINAL->size().height() > temp->height()) { temp->setHeight(MARGINAL->size().height()); }
+  if (OOR_MINIMUM->size().width()  > temp->width ()) { temp->setWidth (OOR_MINIMUM->size().width ()); }
+  if (OOR_MINIMUM->size().height() > temp->height()) { temp->setHeight(OOR_MINIMUM->size().height()); }
+  if (OOR_DOWN->size().width()  > temp->width ()) { temp->setWidth (OOR_DOWN->size().width ()); }
+  if (OOR_DOWN->size().height() > temp->height()) { temp->setHeight(OOR_DOWN->size().height()); }
+  // add a little more x-space: we need 50 pixels left and 50 pixels right of the icon
+  temp->setWidth (temp->width()  + 100);
+  // add a little more y-space: we need 10 pixels above and 20 pixels below the icon
+  temp->setHeight(temp->height() + 30);
+  // up to now: this is the height required to get a decent logo display
+  // now determine height of QLabels to calculate the extra needed height
+  QLabel heightTest( "ABC", 0 );
+  temp->setHeight( temp->height() + 2 * heightTest.sizeHint().height() + 10 );
+  return *temp;
+}
+
 Strength::~Strength ()
 {
   delete NOT_CON_OFFLINE_ADHOC;
@@ -59,76 +86,80 @@ void
 Strength::updateInfo (QPaintEvent *)
 {
   QPainter *strengthpainter = new QPainter (this);
-  sstrength1 = "%1";
-  int sig, noi, strength;
-  double freq;
-  bool validdata = device->get_current_quality (sig, noi, strength);
-  if (useAlternateStrengthCalc) strength = sig - noi;
+  QString sstrength1, sstrength2( i18n("N/A") );
   int mode;
-  sstrength2 = "%1";
-  if (!device->get_device_freq (freq))
+  double freq;
+
+  int sig, noi, strength;
+  bool validdata = device->get_current_quality (sig, noi, strength);
+  if (useAlternateStrengthCalc) 
+	strength = sig - noi;
+
+  if ( device->get_txpower_disabled() )
     {
-      sstrength1 = sstrength1.arg (i18n ("NOT CONNECTED"));
-      sstrength2 = sstrength2.arg (i18n ("N/A"));
+      sstrength1 = i18n("DISABLED");
+      strengthpainter->drawPixmap (50, 10, *NOT_CON_OFFLINE_ADHOC);
+    }
+  else if (!device->get_device_freq (freq))
+    {
+      sstrength1 = i18n("NOT CONNECTED");
       strengthpainter->drawPixmap (50, 10, *NOT_CON_OFFLINE_ADHOC);
     }
   else if (device->get_mode(mode) && mode == 1)
     {
-      sstrength1 = sstrength1.arg (i18n ("AD-HOC MODE"));
-      sstrength2 = sstrength2.arg (i18n ("N/A"));
+      sstrength1 = i18n("AD-HOC MODE");
       strengthpainter->drawPixmap (50, 10, *NOT_CON_OFFLINE_ADHOC);
     }
   else if (validdata && (strength > 45))
     {
-      sstrength1 = sstrength1.arg (i18n ("ULTIMATE"));
-      sstrength2 = sstrength2.arg (strength);
+      sstrength1 = i18n("ULTIMATE");
+      sstrength2 = QString::number(strength);
       strengthpainter->drawPixmap (50, 10, *EXCELLENT);
     }
   else if (validdata && (strength > 35))
     {
-      sstrength1 = sstrength1.arg (i18n ("TOP"));
-      sstrength2 = sstrength2.arg (strength);
+      sstrength1 = i18n("TOP");
+      sstrength2 = QString::number(strength);
       strengthpainter->drawPixmap (50, 10, *EXCELLENT);
     }
   else if (validdata && (strength > 25))
     {
-      sstrength1 = sstrength1.arg (i18n ("EXCELLENT"));
-      sstrength2 = sstrength2.arg (strength);
+      sstrength1 = i18n("EXCELLENT");
+      sstrength2 = QString::number(strength);
       strengthpainter->drawPixmap (50, 10, *EXCELLENT);
     }
   else if (validdata && (strength > 15))
     {
-      sstrength1 = sstrength1.arg (i18n ("GOOD"));
-      sstrength2 = sstrength2.arg (strength);
+      sstrength1 = i18n("GOOD");
+      sstrength2 = QString::number(strength);
       strengthpainter->drawPixmap (50, 10, *GOOD);
     }
   else if (validdata && (strength > 5))
     {
-      sstrength1 = sstrength1.arg (i18n ("WEAK"));
-      sstrength2 = sstrength2.arg (strength);
+      sstrength1 = i18n("WEAK");
+      sstrength2 = QString::number(strength);
       strengthpainter->drawPixmap (50, 10, *MARGINAL);
     }
   else if (validdata && (strength > 0))
     {
-      sstrength1 = sstrength1.arg (i18n ("MINIMUM"));
-      sstrength2 = sstrength2.arg (strength);
+      sstrength1 = i18n("MINIMUM");
+      sstrength2 = QString::number(strength);
       strengthpainter->drawPixmap (50, 10, *OOR_MINIMUM);
     }
   else if (((strength == 0) && (mode == 2)) || (!validdata))
     {
-      sstrength1 = sstrength1.arg (i18n ("OUT OF RANGE"));
-      sstrength2 = sstrength2.arg ("0");
+      sstrength1 = i18n("OUT OF RANGE");
+      sstrength2 = QString::fromLatin1("0");
       strengthpainter->drawPixmap (50, 10, *OOR_DOWN);
     }
   else
     {
-      sstrength1 = sstrength1.arg (i18n ("N/A"));
-      sstrength2 = sstrength2.arg ("N/A");
+      sstrength1 = i18n("N/A");
       strengthpainter->drawPixmap (50, 10, *NOT_CON_OFFLINE_ADHOC);
     };
-  sstrength2 = i18n ("Signal strength: ") + sstrength2;
-  strengthpainter->drawText (5, 50, sstrength1);
-  strengthpainter->drawText (5, 70, sstrength2);
+  sstrength2.prepend( i18n("Signal strength: ") );
+  strengthpainter->drawText (5, 55, sstrength1);
+  strengthpainter->drawText (5, 80, sstrength2);
   delete strengthpainter;
 }
 
